import React, { useEffect, useState } from "react"
import { version } from "../../../package.json"
import { decodeUnicode } from "../../utils/helper"
//import { FormattedMessage } from "react-intl"
import { Card, Statistic, Row, Col, Button, notification } from "antd"
import { CloudUploadOutlined, CloudDownloadOutlined } from "@ant-design/icons"

const Dashboard = () => {
	const [current, setCurrent] = useState("")

	useEffect(() => {
		const handleGitGetPackage = async () => {
			try {
				const fetchGitApi = await fetch(
					`https://api.github.com/repos/${process.env.GATSBY_GITHUB_OWNER}/${process.env.GATSBY_GITHUB_REPO}/contents/package.json`,
					{
						method: "GET",
						headers: {
							authorization:
								"token " + process.env.GATSBY_GITHUB_PERSONAL_ACCESS_TOKEN,
							"Content-Type": "application/json; charset=UTF-8",
						},
					}
				)
					.then((response) => {
						return response.json()
					})
					.catch((error) => {
						console.log("Error ", error)
						notification["error"]({
							message: "Error code " + error.status,
							description: error.statusText,
							duration: 0,
						})
					})
				if (fetchGitApi) {
					const decodeContent = decodeUnicode(fetchGitApi.content)
					if (decodeContent) {
						const packageJson = JSON.parse(decodeContent)
						if (packageJson) {
							const dependencies = packageJson.dependencies
							const currentVersion =
								dependencies[`@maad-dev/gatsby-theme-backend`]
							setCurrent(currentVersion)
						} else {
							setCurrent("api error")
						}
					}
				}
			} catch (error) {
				console.log("Error handleGitGetPackage ", error)
				notification["error"]({
					message: error.name + " code " + error.status,
					description: error.statusText,
					duration: 0,
				})
			}
			return false
		}
		handleGitGetPackage()
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, [])

	return (
		<Row gutter={[16, 16]}>
			<Col xs={24} sm={12}>
				<Card>
					<Statistic
						title="Latest backend version"
						value={version}
						valueStyle={{ color: "#f56a00" }}
						prefix={<CloudUploadOutlined />}
					/>
				</Card>
			</Col>
			<Col xs={24} sm={12}>
				<Card>
					<Statistic
						title="Current backend version"
						value={current}
						valueStyle={{ color: "#000000d9" }}
						prefix={<CloudDownloadOutlined />}
					/>
				</Card>
			</Col>
			<Col span={24}>
				<Card title="Get all new featured">
					<Button type="primary">Upgrade version</Button>
				</Card>
			</Col>
		</Row>
	)
}

export default Dashboard
