import React, { useEffect, useState } from "react"
import gotrue from "../../services/auth"
import Layout from "../../components/Layout"
import { navigate, Link } from "gatsby"
import { notification, Spin, Result, Button } from "antd"

export default function Confirm() {
	const [status, setStatus] = useState({ process: true })

	const getQueryVariable = (variable) => {
		var query = window.location.href
		var vars = query.split("#")
		for (var i = 0; i < vars.length; i++) {
			var pair = vars[i].split("=")
			if (pair[0] === variable) {
				return pair[1]
			}
		}
		return false
	}

	useEffect(() => {
		const tokenConfirm = getQueryVariable("confirmation_token")
		if (tokenConfirm) {
			gotrue
				.confirm(tokenConfirm, true)
				.then((response) => {
					notification["success"]({
						message: "Congratulations!",
						description: response.email + " was successfully confirmed.",
						duration: 0,
					})
					navigate(`/backend/dashboard`)
					return null
				})
				.catch((error) => {
					setStatus({ process: false })
					console.log("error ", error)
					notification["error"]({
						message: error.name + " code " + error.status,
						description: error.json.msg,
						duration: 0,
					})
				})
		} else {
			navigate(`/auth/signin`)
			return null
		}
	}, [])

	return (
		<Layout>
			<div className="pageContainer" style={{ textAlign: "center" }}>
				{status.process ? (
					<Spin tip="Processing..." />
				) : (
					<Result
						status="error"
						title="Confirm Failed"
						subTitle="Please contact webmasters!"
						extra={
							<Button type="primary">
								<Link to="/">Go Home</Link>
							</Button>
						}
					/>
				)}
			</div>
		</Layout>
	)
}
